"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "ValidationErrors", {
    enumerable: true,
    get: function() {
        return ValidationErrors;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _f36icons = require("@contentful/f36-icons");
const _fieldeditorshared = require("@contentful/field-editor-shared");
const _styles = /*#__PURE__*/ _interop_require_wildcard(require("./styles"));
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
function UniquenessError(props) {
    const [state, setState] = _react.useState({
        loading: true,
        entries: []
    });
    const contentTypesById = _react.useMemo(()=>props.space.getCachedContentTypes().reduce((prev, ct)=>({
                ...prev,
                [ct.sys.id]: ct
            }), {}), [
        props.space
    ]);
    const getTitle = _react.useCallback((entry)=>_fieldeditorshared.entityHelpers.getEntryTitle({
            entry,
            defaultTitle: 'Untitled',
            localeCode: props.localeCode,
            defaultLocaleCode: props.defaultLocaleCode,
            contentType: contentTypesById[entry.sys.contentType.sys.id]
        }), [
        props.localeCode,
        props.defaultLocaleCode,
        contentTypesById
    ]);
    let conflicting = [];
    if ('conflicting' in props.error) {
        conflicting = props.error.conflicting;
    }
    _react.useEffect(()=>{
        const entryIds = state.entries.map((entry)=>entry.id);
        const conflictIds = conflicting.map((entry)=>entry.sys.id);
        if (conflictIds.every((id)=>entryIds.includes(id))) {
            return;
        }
        setState((state)=>({
                ...state,
                loading: true
            }));
        const query = {
            'sys.id[in]': conflictIds.join(',')
        };
        props.space.getEntries(query).then(({ items })=>{
            const entries = items.map((entry)=>({
                    id: entry.sys.id,
                    title: getTitle(entry),
                    href: props.getEntryURL(entry)
                }));
            setState({
                loading: false,
                entries
            });
        });
    }, [
        getTitle,
        state.entries,
        conflicting,
        props.space.getEntries,
        props.getEntryURL
    ]);
    return /*#__PURE__*/ _react.createElement(_f36components.List, {
        className: _styles.errorList,
        testId: "validation-errors-uniqueness"
    }, /*#__PURE__*/ _react.createElement(_f36components.ListItem, {
        className: _styles.entryLink
    }, state.loading ? /*#__PURE__*/ _react.createElement("div", null, "Loading title for conflicting entry…") : state.entries.map((entry)=>/*#__PURE__*/ _react.createElement(_f36components.TextLink, {
            key: entry.id,
            href: entry.href,
            icon: /*#__PURE__*/ _react.createElement(_f36icons.ExternalLinkIcon, null),
            alignIcon: "end",
            variant: "negative",
            target: "_blank",
            rel: "noopener noreferrer"
        }, entry.title))));
}
function ValidationErrors(props) {
    const [errors, setErrors] = _react.useState([]);
    _react.useEffect(()=>{
        const onErrors = (errors)=>{
            setErrors(errors || []);
        };
        return props.field.onSchemaErrorsChanged(onErrors);
    }, [
        props.field
    ]);
    if (errors.length === 0) {
        return null;
    }
    return /*#__PURE__*/ _react.createElement(_f36components.List, {
        className: _styles.errorList,
        testId: "validation-errors"
    }, errors.map((error, index)=>{
        return /*#__PURE__*/ _react.createElement("li", {
            key: index,
            role: "status",
            "aria-roledescription": "field-locale-schema",
            "data-error-code": `entry.schema.${error.name}`,
            className: _styles.errorItem
        }, /*#__PURE__*/ _react.createElement(_f36icons.InfoCircleIcon, {
            variant: "negative"
        }), /*#__PURE__*/ _react.createElement("div", {
            className: _styles.errorMessage
        }, props.errorMessageOverride?.(error.message) ?? error.message, error.name === 'unique' && /*#__PURE__*/ _react.createElement(UniquenessError, {
            error: error,
            space: props.space,
            localeCode: props.field.locale,
            defaultLocaleCode: props.locales.default,
            getEntryURL: props.getEntryURL
        })));
    }));
}
