"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
require("@testing-library/jest-dom/extend-expect");
const _fieldeditortestutils = /*#__PURE__*/ _interop_require_wildcard(require("@contentful/field-editor-test-utils"));
const _react1 = require("@testing-library/react");
const _ValidationErrors = require("./ValidationErrors");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
(0, _react1.configure)({
    testIdAttribute: 'data-test-id'
});
const displayField = 'my-title';
const contentTypeId = 'my-content-type';
const getCachedContentTypes = ()=>[
        {
            displayField,
            fields: [
                {
                    id: displayField
                }
            ],
            sys: {
                id: 'my-content-type'
            }
        }
    ];
const createEntry = (id)=>({
        fields: {
            [displayField]: {
                'en-US': 'entry-title-for-' + id
            }
        },
        sys: {
            id,
            contentType: {
                sys: {
                    id: contentTypeId
                }
            }
        }
    });
describe('ValidationErrors', ()=>{
    afterEach(_react1.cleanup);
    it('renders without crashing', ()=>{
        const [field] = _fieldeditortestutils.createFakeFieldAPI();
        const { container } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_ValidationErrors.ValidationErrors, {
            field: field,
            space: _fieldeditortestutils.createFakeSpaceAPI(),
            locales: _fieldeditortestutils.createFakeLocalesAPI(),
            getEntryURL: (entry)=>`url.${entry.sys.id}`
        }));
        expect(container).toBeEmptyDOMElement();
    });
    it('should render the list of error messages', async ()=>{
        const errors = [
            {
                name: 'test-error',
                message: 'The input is invalid',
                path: []
            }
        ];
        const [field, emitter] = _fieldeditortestutils.createFakeFieldAPI();
        const { findByText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_ValidationErrors.ValidationErrors, {
            field: field,
            space: _fieldeditortestutils.createFakeSpaceAPI(),
            locales: _fieldeditortestutils.createFakeLocalesAPI(),
            getEntryURL: (entry)=>`url.${entry.sys.id}`
        }));
        (0, _react1.act)(()=>{
            emitter.emit('onSchemaErrorsChanged', errors);
        });
        await Promise.all(errors.map((e)=>{
            if (e.message) {
                return findByText(e.message);
            } else {
                return Promise.reject();
            }
        }));
    });
    it('should fetch & render links to duplicated entries', async ()=>{
        const ids = [
            'id-0',
            'id-1',
            'id-2'
        ];
        const errors = [
            {
                name: 'unique',
                message: 'entry is duplicated',
                conflicting: ids.map((id)=>({
                        sys: {
                            id,
                            type: 'Link',
                            linkType: 'Entry'
                        }
                    })),
                path: []
            }
        ];
        const [field, emitter] = _fieldeditortestutils.createFakeFieldAPI();
        const space = _fieldeditortestutils.createFakeSpaceAPI((api)=>({
                ...api,
                getCachedContentTypes,
                getEntries: jest.fn().mockResolvedValue({
                    items: ids.map(createEntry)
                })
            }));
        const { findByText, findAllByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_ValidationErrors.ValidationErrors, {
            field: field,
            space: space,
            locales: _fieldeditortestutils.createFakeLocalesAPI(),
            getEntryURL: (entry)=>`url.${entry.sys.id}`
        }));
        (0, _react1.act)(()=>{
            emitter.emit('onSchemaErrorsChanged', errors);
        });
        await findByText(/Loading title for conflicting entry/);
        const links = await findAllByTestId('cf-ui-text-link');
        links.forEach((link, index)=>{
            expect(link).toHaveAttribute('href', 'url.id-' + index);
            expect(link).toHaveTextContent('entry-title-for-id-' + index);
        });
    });
});
